@@ -26,7 +26,7 @@ EventPred = function(parameters) {
   parameters$random_seed = random_seed
 
   # Set the seed of R's random number generator.
-  # It also takes effect to Rcpp randome generation functions.
+  # It also takes effect to Rcpp random generation functions.
   # https://stackoverflow.com/questions/60119621/get-the-same-sample-of-integers-from-rcpp-as-base-r
   suppressWarnings(RNGkind(sample.kind = "Rounding"))
   set.seed(random_seed)
@@ -122,7 +122,7 @@ EventPred = function(parameters) {
   }
 
   if (!is.null(parameters$ncores)) {
-
+    # nocov start
     # Maximum number of cores
     max_ncores = parallel::detectCores()
 
@@ -137,7 +137,7 @@ EventPred = function(parameters) {
                            c("Value"),
                            "int",
                            NA) 
-
+    # nocov end
   } else {
     parameters$ncores = 1
   }
@@ -153,7 +153,7 @@ EventPred = function(parameters) {
   ncores = parameters$ncores
 
   if (ncores > 1) {
-
+    # nocov start
     cl = parallel::makeCluster(ncores)
 
     # Export all functions in the global environment to each node
@@ -184,7 +184,7 @@ EventPred = function(parameters) {
 
     results = list(number_events = number_events,
                  posterior_distributions = simulation_list[[1]]$posterior_distributions)
-
+    # nocov end
   } else {
 
     results = EventPredRSingleCore(parameters)
@@ -348,7 +348,7 @@ EventPredReportDoc = function(results) {
 
    # Error checks
 
-   if (class(results) != "EventPredResults") stop("The object was not created by the EventPred function", call. = FALSE)
+   if (!is(results, "EventPredResults")) stop("The object was not created by the EventPred function", call. = FALSE)
 
   #############################################################################
 
